@@ -1,7 +1,7 @@
 #' @title wTO
 #' @description Calculates the weighted topologycal overlap (wTO)
 #' between a set of Nodes and the Overlapping nodes. This function implements the method from Nowick (2009).
-#' @param A Is the weighted adjency matrix (correlation matrix).
+#' @param A_TF Is the weighted adjency matrix (correlation matrix).
 #' @param sign ("abs", "sign") if the user wants to use the absolute correlation or the signed correlation.
 #' @return A matrix containing the wTO values.
 #' @export
@@ -10,17 +10,18 @@
 #' @importFrom Rfast Crossprod transpose
 
 
-wTO = function(A,  sign = c("abs", "sign")){
+wTO = function(A_TF,  sign = c("abs", "sign")){
 
+  A_TF = as.matrix(A_TF)
   if(sign %in% c("abs", "absolute")){
-    A = abs(A)
+    A_TF = abs(A_TF)
   }
-  A_TF = as.data.frame(subset(A, select = row.names(A)))
-  C = Rfast::Crossprod(A, Rfast::transpose(A))
+  # A_TF = as.data.frame(subset(A, select = row.names(A)))
+  C = Rfast::Crossprod(A_TF, Rfast::transpose(A_TF))
   
   W = C + A_TF ###
   K  = matrix(NA, nrow(A_TF), ncol(A_TF))
-  KI = rowSums(abs(A), na.rm = T)
+  KI = rowSums(abs(A_TF), na.rm = T)
   for( ii in 1: nrow(A_TF)){
     for( jj in 1: ncol(A_TF)){
       K[ii,jj] = min(KI[ii], KI[jj])
